@@ -432,15 +432,26 @@ $s = time + $factor;
 while (time < $s) {
     my $image = $F->load_image(
         {
-            'x' => 0,
-              'y' => 0,
+            'x'      => 0,
+            'y'      => 0,
             'width'  => rand($XX),
-              'height' => rand($YY),
-              'file'   => 'examples/RWBY_Faces.png'
+            'height' => rand($YY),
+            'file'   => 'examples/testpattern.jpg'
         }
     );
     $F->blit_write($image);
 }
+my $image = $F->load_image(
+    {
+        'x'      => 0,
+        'y'      => 0,
+        'width'  => $XX,
+        'height' => $YY,
+        'file'   => 'examples/testpattern.jpg'
+    }
+);
+$F->blit_write($image);
+sleep $factor;
 
 print_it($F, 'Testing Image blitting');
 
